#
# spec file for package perl-Font-FreeType
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Font-FreeType
Version:        0.16
Release:        bp153.1.16
%define cpan_name Font-FreeType
Summary:        Read Font Files and Render Glyphs From Perl Using Freetype2
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DM/DMOL/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Devel::CheckLib)
BuildRequires:  perl(File::Which)
BuildRequires:  perl(Test::Warnings)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  freetype2-devel
# MANUAL END

%description
This module allows Perl programs to conveniently read information from font
files. All the font access is done through the FreeType2 library, which
supports many formats. It can render images of characters with high-quality
hinting and antialiasing, extract metrics information, and extract the
outlines of characters in scalable formats like TrueType.

Warning: this module is currently in 'beta' stage. It'll be another release
or two before it stabilizes. The API may change in ways that break programs
based on it, but I don't think it will change much. Some of the values
returned may be wrong, or not scaled correctly. See the _TODO_ file to get
a handle on how far along this work is. Contributions welcome, particularly
if you know more than I do (which isn't much) about fonts and the FreeType2
library.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples TODO

%changelog
* Fri Jun  5 2020 Max Lin <mlin@suse.com>
- updated to 0.16
  see /usr/share/doc/packages/perl-Font-FreeType/Changes
  0.16 2020-05-12 dmol@cpan.org
  - fix cpan-testers failures
  - fix C++ usages instead of C
  0.15 2020-05-11 dmol@cpan.org
  - fix tests for RT#132543
  0.14 2020-05-11 htl10@users.sourceforge.net
  - update glyph->load method()
  0.13 2018-10-19 dmol@cpan.org
  - update tests, as freetype changed font metrices under hood
  0.12 2018-08-14 htl10@users.sourceforge.net
  - Added the face->load_flags getter and setter methods
  - Fixed bugs loading glyph index 0 by name (".notdef") or by index.
  0.12 2018-08-11 htl10@users.sourceforge.net
  - Added an explicit glyph->load method
  0.12 2018-08-12 dmol@cpan.org
  - Fix MANIFEST
  0.11 2018-08-11 dmol@cpan.org
  - Added FT_LOAD_COMPUTE_METRICS load flag (HinTak)
  - Added face->foreach_glyph method for iterating over all glyphs
    (some of them don't necessarily have a unicode point) (HinTak)
* Mon Mar 19 2018 coolo@suse.com
- updated to 0.10
  see /usr/share/doc/packages/perl-Font-FreeType/Changes
  0.10_1 2018-03-18 dmol@cpan.org
  - No changes since 0.10_1
  0.10_1 2018-03-17 dmol@cpan.org
  - Allow to lookup glyphs by name (mauzo)
* Thu Oct 19 2017 coolo@suse.com
- updated to 0.09
  see /usr/share/doc/packages/perl-Font-FreeType/Changes
  0.09 2017-10-18 dmol@cpan.org
  - Fallback to default charmap for 2.8.1 for backward-compatibility
    for FNT-fonts
  0.08_1 2015-05-02 dmol@cpan.org
  - Added .gitignore file (htl10@users.sourceforge.net)
  - Remove generated files from MANIFEST listing (htl10@users.sourceforge.net)
  - Removed unused variables and silenced some compiler warnings
    (htl10@users.sourceforge.net)
* Mon Sep 28 2015 coolo@suse.com
- updated to 0.07
  see /usr/share/doc/packages/perl-Font-FreeType/Changes
  0.07 2015-09-27 dmol@cpan.org
  - No changes since 0.07_2
  0.07_2 2015-09-24 dmol@cpan.org
  - Try to support utf8_to_uvchr_buf for older perls
  0.07_1 2015-09-24 dmol@cpan.org
  - Fix UTF-8 string usage on non-intel architectures (GH#17)
* Sat Jul 18 2015 coolo@suse.com
- updated to 0.06
  see /usr/share/doc/packages/perl-Font-FreeType/Changes
  0.06 2015-01-27 dmol@cpan.org
  - No changes since 0.06_1
  0.06_1 2015-01-27 dmol@cpan.org
  - Allow optionally fallback to missing glyph
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.05
  see /usr/share/doc/packages/perl-Font-FreeType/Changes
- build.patch no longer needed
* Thu Nov 17 2011 coolo@suse.com
- use original tar
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sun Aug 12 2007 aj@suse.de
- Fix spec file to build.
* Fri Aug 10 2007 mfabian@suse.de
- fix build.
* Thu Jun 28 2007 mfabian@suse.de
- new package: perl-Font-Freetype version 0.03.
